@@ -7,8 +7,8 @@ from .models.features import *
 from .models.products import *
 from .aio.client import AsyncClient as Autumn
 
-
-__version__ = "1.5.1"
+__title__ = "autumn"
+__version__ = "2.1.0"
 __license__ = "MIT"
 __author__ = "justanotherbyte"
 __copyright__ = "Copyright 2025 justanotherbyte"
@@ -16,3 +16,4 @@ __copyright__ = "Copyright 2025 justanotherbyte"
 
 BASE_URL = "https://api.useautumn.com"
 VERSION = "v1"
+LATEST_API_VERSION = "1.2"
