@@ -7,15 +7,16 @@ from .features import Features
 from .products import Products
 from .http import HTTPClient
 from .utils import _build_payload
-from .models.meta import AttachOption
 from .models.response import (
     AttachResponse,
     CheckResponse,
+    CheckoutResponse,
     TrackResponse,
 )
 
 if TYPE_CHECKING:
     from .models.features import Feature
+    from .models.meta import AttachOption
     from .models.meta import CustomerData
 
 
@@ -130,7 +131,7 @@ class Client:
 
         Returns
         -------
-        :class:`~autumn.types.response.AttachResponse`
+        :class:`~autumn.models.response.AttachResponse`
             The response from the API.
         """
 
@@ -183,7 +184,7 @@ class Client:
 
         Returns
         -------
-        :class:`~autumn.types.response.CheckResponse`
+        :class:`~autumn.models.response.CheckResponse`
             The response from the API.
         """
 
@@ -197,7 +198,7 @@ class Client:
     def track(
         self,
         customer_id: str,
-        feature_id: str,
+        feature_id: Optional[str] = None,
         *,
         value: int = 1,
         entity_id: Optional[str] = None,
@@ -215,8 +216,8 @@ class Client:
         ----------
         customer_id: str
             The ID of the customer to track.
-        feature_id: str
-            The ID of the feature to track.
+        feature_id: Optional[str]
+            The ID of the feature to track. This or the ``event_name`` must be provided.
         value: int
             The amount of the feature to deduct.
         entity_id: Optional[str]
@@ -232,8 +233,36 @@ class Client:
 
         Returns
         -------
-        :class:`~autumn.types.response.TrackResponse`
+        :class:`~autumn.models.response.TrackResponse`
             The response from the API.
         """
+        assert feature_id or event_name, "Either feature_id or event_name must be provided"
         payload = _build_payload(locals(), self.track)
         return self.http.request("POST", "/track", TrackResponse, json=payload)
+
+    def checkout(
+        self,
+        customer_id: str,
+        product_id: str,
+        *,
+        success_url: Optional[str] = None,
+    ) -> CheckoutResponse:
+        """
+        Checkout a product for a customer.
+
+        Parameters
+        ----------
+        customer_id: str
+            The ID of the customer to checkout.
+        product_id: str
+            The ID of the product to checkout.
+        success_url: Optional[str]
+            The URL to redirect to after a successful checkout.
+
+        Returns
+        -------
+        :class:`~autumn.models.response.CheckoutResponse`
+            The response from the API.
+        """
+        payload = _build_payload(locals(), self.checkout)
+        return self.http.request("POST", "/checkout", CheckoutResponse, json=payload)
