@@ -12,6 +12,7 @@ from typing import (
     TYPE_CHECKING,
 )
 
+from .models.meta import Empty
 from .models.customers import Customer
 from .models.response import BillingPortalResponse, PricingTableResponse
 from .utils import _build_payload
@@ -56,7 +57,7 @@ class Customers(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.customers.Customer`
+        :class:`~autumn.models.customers.Customer`
             The customer.
         """
         return self._http.request("GET", f"/customers/{customer_id}", Customer)
@@ -106,7 +107,7 @@ class Customers(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.customers.Customer`
+        :class:`~autumn.models.customers.Customer`
             The created customer.
         """
         payload = _build_payload(locals(), self.create)  # type: ignore
@@ -157,7 +158,7 @@ class Customers(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.customers.Customer`
+        :class:`~autumn.models.customers.Customer`
             The updated customer.
         """
         payload = _build_payload(locals(), self.update, ignore={"customer_id"})  # type: ignore
@@ -165,6 +166,24 @@ class Customers(Generic[T_HttpClient]):
             "POST", f"/customers/{customer_id}", Customer, json=payload
         )
 
+    @overload
+    def delete(
+        self: "Customers[HTTPClient]",
+        customer_id: str
+    ) -> Empty: ...
+
+    @overload
+    def delete(
+        self: "Customers[AsyncHTTPClient]",
+        customer_id: str
+    ) -> Coroutine[Any, Any, Empty]: ...
+
+    def delete(
+        self,
+        customer_id: str
+    ) -> Union[Empty, Coroutine[Any, Any, Empty]]:
+        return self._http.request("DELETE", f"/customers/{customer_id}", Empty)
+
     @overload
     def get_billing_portal(
         self: "Customers[HTTPClient]",
@@ -200,7 +219,7 @@ class Customers(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.BillingPortalResponse`
+        :class:`~autumn.models.response.BillingPortalResponse`
             The billing portal URL.
         """
         payload = _build_payload(
@@ -239,7 +258,7 @@ class Customers(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.PricingTableResponse`
+        :class:`~autumn.models.response.PricingTableResponse`
             The pricing table.
         """
         params = {"customer_id": customer_id}
