@@ -12,13 +12,15 @@ from typing import (
     TYPE_CHECKING,
 )
 
-from .types.products import ProductItem, FreeTrial
-from .types.response import (
+from .models.meta import Empty
+from .models.products import ProductItem, FreeTrial
+from .models.response import (
     CreateProductResponse,
     GetProductResponse,
     ReferralCodeResponse,
     ReferralRedeemResponse,
     ProductCancelResponse,
+    ListProductResponse
 )
 from .utils import _build_payload
 
@@ -111,7 +113,7 @@ class Products(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.CreateProductResponse`
+        :class:`~autumn.models.response.CreateProductResponse`
             The response from the API.
         """
         payload = _build_payload(locals(), self.create)  # type: ignore
@@ -145,11 +147,77 @@ class Products(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.GetProductResponse`
+        :class:`~autumn.models.response.GetProductResponse`
             The response from the API.
         """
         return self._http.request("GET", f"/products/{id}", GetProductResponse)
 
+    @overload
+    def list(self: "Products[HTTPClient]", customer_id: str) -> ListProductResponse:
+        ...
+
+    @overload
+    def list(self: "Products[AsyncHTTPClient]", customer_id: str) -> Coroutine[Any, Any, ListProductResponse]:
+        ...
+
+    def list(self, customer_id: str) -> Union[ListProductResponse, Coroutine[Any, Any, ListProductResponse]]:
+        return self._http.request("GET", f"/products?customer_id={customer_id}", ListProductResponse)
+
+    @overload
+    def update(
+        self: "Products[HTTPClient]",
+        id: str,
+        *,
+        name: str,
+        is_add_on: bool = False,
+        is_default: bool = False,
+        items: Optional[List[ProductItem]] = None,
+        free_trial: Optional[FreeTrial] = None,
+    ) -> Empty: ...
+
+    @overload
+    def update(
+        self: "Products[AsyncHTTPClient]",
+        id: str,
+        *,
+        name: str,
+        is_add_on: bool = False,
+        is_default: bool = False,
+        items: Optional[List[ProductItem]] = None,
+        free_trial: Optional[FreeTrial] = None,
+    ) -> Coroutine[Any, Any, Empty]: ...
+
+    def update(
+        self,
+        id: str,
+        *,
+        name: str,
+        is_add_on: bool = False,
+        is_default: bool = False,
+        items: Optional[List[ProductItem]] = None,
+        free_trial: Optional[FreeTrial] = None,
+    ) -> Union[Empty, Coroutine[Any, Any, Empty]]:
+        payload = _build_payload(locals(), self.update) # type: ignore
+        return self._http.request("POST", f"/products/{id}", Empty, json=payload)
+
+    @overload
+    def delete(
+        self: "Products[HTTPClient]",
+        id: str
+    ) -> Empty: ...
+
+    @overload
+    def delete(
+        self: "Products[AsyncHTTPClient]",
+        id: str
+    ) -> Empty: ...
+
+    def delete(
+        self,
+        id: str
+    ) -> Union[Empty, Coroutine[Any, Any, Empty]]:
+        return self._http.request("DELETE", f"/products/{id}", Empty)
+
     @overload
     def get_referral_code(
         self: "Products[HTTPClient]",
@@ -182,7 +250,7 @@ class Products(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.ReferralCodeResponse`
+        :class:`~autumn.models.response.ReferralCodeResponse`
             The response from the API.
         """
 
@@ -231,7 +299,7 @@ class Products(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.ReferralRedeemResponse`
+        :class:`~autumn.models.response.ReferralRedeemResponse`
             The response from the API.
         """
         payload = _build_payload(locals(), self.redeem_referral_code)  # type: ignore
@@ -249,7 +317,7 @@ class Products(Generic[T_HttpClient]):
         product_id: str,
         *,
         entity_id: Optional[str] = None,
-        cancel_immediately: bool = False
+        cancel_immediately: bool = False,
     ) -> ProductCancelResponse: ...
 
     @overload
@@ -259,7 +327,7 @@ class Products(Generic[T_HttpClient]):
         product_id: str,
         *,
         entity_id: Optional[str] = None,
-        cancel_immediately: bool = False
+        cancel_immediately: bool = False,
     ) -> Coroutine[Any, Any, ProductCancelResponse]: ...
 
     def cancel(
@@ -268,7 +336,7 @@ class Products(Generic[T_HttpClient]):
         product_id: str,
         *,
         entity_id: Optional[str] = None,
-        cancel_immediately: bool = False
+        cancel_immediately: bool = False,
     ) -> Union[ProductCancelResponse, Coroutine[Any, Any, ProductCancelResponse]]:
         """Cancel a product for a customer.
 
@@ -287,7 +355,7 @@ class Products(Generic[T_HttpClient]):
 
         Returns
         -------
-        :class:`~autumn.types.response.ProductCancelResponse`
+        :class:`~autumn.models.response.ProductCancelResponse`
             The response from the API.
         """
         payload = _build_payload(locals(), self.cancel_product)  # type: ignore
